/******************************************************************************
**** Template Instructions ****************************************************
*******************************************************************************
*   Use Ctrl-Shift-M to set Template Parameters
*       -or-
*   From the Standard Toolbar, navigate to:
*       Query->Specify Values for Template Parameters
*
*   Parameter                 | Description
*   --------------------------|------------------------------------------------
*   Database                  | The name of the database {iCMSA, iDTSA, iDTFM}.
*                             |   This is only used in the "use" statement at
*                             |   the top of the script.
*   Fact                      | The name of this fact.  The name will be
*                             |   prepended with "Fact", so if you enter "Sample"
*                             |   the dimension will be named "FactSample".  This
*                             |   is used extensively throughout the script.
*   Column                    | This is the attribute being added to the fact.
*   Column Type               | This is the datatype for the new column.
*   Column Description        | A description of the column to be shown
*							  |   in the dictionary.
*   Column Source             | The source location to be shown in dictionary.
*
******************************************************************************/
use <Database,,iCMSA>
go

/****************************************************************************************************************************************
															SECTION A
****************************************************************************************************************************************/

/******************************************************************************
	1. Add column to Stage and Final tables
******************************************************************************/

alter table Stage.Fact<Fact,,Sample> add <Column,,SampleColumn> <Column Type,,varchar(50)> default 0 not null
alter table Final.Fact<Fact,,Sample> add <Column,,SampleColumn> <Column Type,,varchar(50)> default 0 not null
go

/* Add dictionary entries */
exec HEA.UpdateExtendedProperty @Name = 'MS_Description', @Value = '<Column Description,,Sample Attribute>', @Level0Object = 'Stage', @Level1Object = 'Fact<Fact,,Sample>', @Level2Object = '<Column,,SampleColumn>'
exec HEA.UpdateExtendedProperty @Name = 'iStrategy_Source', @Value = '<Column Source,,>', @Level0Object = 'Stage', @Level1Object = 'Fact<Fact,,Sample>', @Level2Object = '<Column,,SampleColumn>'
exec HEA.CopyExtendedProperty @FromLevel0Name = 'Stage', @FromLevel1Name = 'Fact<Fact,,Sample>', @FromLevel2Name = '<Column,,SampleColumn>', @ToLevel0Name = 'Final', @ToLevel1Name = 'Fact<Fact,,Sample>', @ToLevel2Name = '<Column,,SampleColumn>'
go

/****************************************************************************************************************************************
															SECTION B
****************************************************************************************************************************************/

/******************************************************************************
	1. Add Helper to populate the custom attribute
******************************************************************************/

if  exists (
    select *
    from
        sys.objects
    where
        object_id = object_id(N'CustomStage.HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>') and
        type in (N'U'))
begin
    drop procedure CustomStage.HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>
end
go

create procedure CustomStage.HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>
as

-- Insert your code here
update
	f
set
	<Column,,SampleColumn> = '0'
from
	Stage.Fact<Fact,,Sample> f
go

/******************************************************************************
	2. Add dictionary property for Helper 
******************************************************************************/
exec HEA.UpdateExtendedProperty @Name = 'MS_Description', @Value = 'Helper procedure for Fact<Fact,,Sample> to populate <Column,,SampleColumn>', @Level0Object = 'CustomStage', @Level1Object = 'HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>'
go

/****************************************************************************************************************************************
															SECTION C
****************************************************************************************************************************************/

/******************************************************************************
	1. Add entry to HEA.EntityHelper
******************************************************************************/
insert into HEA.EntityHelper (EntityCode, Type, ExecutionOrder, Helper, IsCustom)
select 'Fact<Fact,,Sample>', 'Stage', 10, 'CustomStage.HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>', 1
where not exists (select 1 from HEA.EntityHelper where EntityCode = 'Fact<Fact,,Sample>' and Helper = 'CustomStage.HelperFact<Fact,,Sample>Stage<Column,,SampleColumn>')
go
